"""This module contains the embedded images for Entity Pictures."""
from __future__ import annotations

PICTURE_ITEMS = {
    "batterier": "",
    "elektronik": "",
    "dagrenovation": "",
    "farligtaffald": "",
    "farligtaffaldmiljoboks": "",
    "flis": "",
    "genbrug": "",
    "glas": "",
    "glasplast": "",
    "haveaffald": "",
    "jern": "",
    "metalglas": "",
    "pap": "",
    "papir": "",
    "papirglas": "",
    "papirglasdaaser": "",
    "papirglasmetalplast": "",
    "papirmetal": "",
    "pappapir": "",
    "pappapirglasmetal": "",
    "pappi": "",
    "plast": "",
    "plastmadkarton": "",
    "plastmetal": "",
    "plastmetalmadmdk": "",
    "plastmetalpapir": "",
    "restaffaldmadaffald": "",
    "storskrald": "",
    "storskraldogtekstilaffald": "",
    "tekstil": "",
}
